#include "SPI.h"
#include "NRFLite.h"
#include <Wire.h>
#include <avr/wdt.h>

const static uint8_t RADIO_ID = 0;       // Our radio's id.  The transmitter will send to this id.
const static uint8_t PIN_RADIO_CE = 7;
const static uint8_t PIN_RADIO_CSN = 10;

struct RadioPacket // Any packet up to 32 bytes can be sent.
{
  float valuev;
};


float batlow = 56.50; // 1st mosfet switch off voltage
float bathigh = 56.50; // 2nd mosfet switch off voltage
int ledPin5 = 5; // mosfet pin 1
int ledPin6 = 6; // mosfet pin 2
float value;
int Rflag = 0; // initial flag set to zero so will only start to drive mosfets once voltage is recieved.
int minpwm = 50;

NRFLite _radio;
RadioPacket _radioData;

unsigned long previousMillis = 0; // mosfet update timer
const long interval = 10000;

unsigned long previousMillis1 = 0; // Nrf24l01 update timer
const long interval1 = 1000;



void writepin () // Actully write data to regulator mosfets
{
  if (value < batlow && Rflag == 1 ) {
    analogWrite (ledPin5, 255 );
    Serial.println ("low high ");

  } else {
    analogWrite (ledPin5, minpwm);
    Serial.println ("low low ");
  }

  if (value < bathigh && Rflag == 1) {
    analogWrite  (ledPin6, 255 );
    Serial.println ("high high ");

  }
  else {
    Serial.println ("high low ");
    analogWrite  (ledPin6, minpwm);
  }

  value = 0;
}

void setup()
{
  Serial.begin(115200);
  wdt_disable(); // disable Watch dog timer
  Serial.println("START UP");
  pinMode(A4, OUTPUT); // red led on mine as a startup notifier
  pinMode(A2, OUTPUT); // green led heartbeat when recieving a signal, stops flashing no signal
  digitalWrite (A4, HIGH);
  delay (500);
  digitalWrite (A4, LOW);
  wdt_enable(WDTO_8S); // Enable WDT as this is a pretty important device and needs reliability


  if (!_radio.init(RADIO_ID, PIN_RADIO_CE, PIN_RADIO_CSN, NRFLite::BITRATE2MBPS, 50))
  {
    Serial.println("Cannot communicate with radio");
    while (1); // Wait here forever., trigger WDT as well
  }
  pinMode(ledPin5, OUTPUT);
  pinMode(ledPin6, OUTPUT);
  analogWrite (ledPin5, minpwm); // set to " low " as default
  analogWrite  (ledPin6, minpwm);

}

void loop()
{
  unsigned long currentMillis = millis();


  if (currentMillis - previousMillis >= interval) {
    previousMillis = currentMillis;

    writepin();
    Rflag = (0); // reset our recieved flag to 0
  }

  if (currentMillis - previousMillis1 >= interval1) {
    previousMillis1 = currentMillis;

    Serial.println ("CHECK NRF24L01");
    while (_radio.hasData())
    {
      _radio.readData(&_radioData); // Note how '&' must be placed in front of the variable name.

      Serial.println (" recieved ");
      digitalWrite(A2, HIGH); // trigger heartbeat led to let you know I recieved something, if goes solid then recieved garbled or " funky " info
      Serial.println(_radioData.valuev);
      value = (_radioData.valuev);
      if (value < 45.00) {
        delay (9000); // trigger WDT if garbled or " noise " picked up
      } else if (value > 62.00) {
        delay (9000); // same as above, has to pick up a resonable voltage 
      }
      Rflag = (1); // set our info recieved flag 1 so will drive mosfets
      Serial.println (Rflag);
      wdt_reset(); // reset WDT flag as Ive gone through Loop .... otherwise Ill reset chip
      digitalWrite(A2, LOW); // ok turn it off now
    }
  }


}
